@@ -176,7 +176,7 @@ class CommitWidget(QWidget):
         self.msghistory = []
         self.repo = repo = self.stwidget.repo
         self.runner = cmdui.Runner(not embedded, self)
-        self.runner.setTitle(_('Commit'))
+        self.runner.setTitle(_('Commit', 'window title'))
         self.runner.output.connect(self.output)
         self.runner.progress.connect(self.progress)
         self.runner.makeLogVisible.connect(self.makeLogVisible)
@@ -188,6 +188,7 @@ class CommitWidget(QWidget):
 
         self.opts['pushafter'] = repo.ui.config('tortoisehg', 'cipushafter', '')
         self.opts['autoinc'] = repo.ui.config('tortoisehg', 'autoinc', '')
+        self.stwidget.opts['ciexclude'] = repo.ui.config('tortoisehg', 'ciexclude', '')
 
         layout = QVBoxLayout()
         layout.setContentsMargins(2, 2, 2, 2)
@@ -257,7 +258,10 @@ class CommitWidget(QWidget):
         # add our splitter where the docf used to be
         self.stwidget.split.addWidget(self.split)
         self.msgte = msgte
-        QShortcut(QKeySequence('Ctrl+Return'), self, self.commit)
+        QShortcut(QKeySequence('Ctrl+Return'), self, self.commit).setContext(
+                  Qt.WidgetWithChildrenShortcut)
+        QShortcut(QKeySequence('Ctrl+Enter'), self, self.commit).setContext(
+                  Qt.WidgetWithChildrenShortcut)
 
     @pyqtSlot(QString, QString)
     def fileDisplayed(self, wfile, contents):
@@ -618,13 +622,13 @@ class CommitWidget(QWidget):
         self.commitButtonEnable.emit(False)
         self.runner.run(*commandlines)
         self.stopAction.setEnabled(True)
-        self.progress.emit(*cmdui.startProgress(_('Commit'), ''))
+        self.progress.emit(*cmdui.startProgress(_('Commit', 'start progress'), ''))
 
     def stop(self):
         self.runner.cancel()
 
     def commandFinished(self, ret):
-        self.progress.emit(*cmdui.stopProgress(_('Commit')))
+        self.progress.emit(*cmdui.stopProgress(_('Commit', 'stop progress')))
         self.stopAction.setEnabled(False)
         self.commitButtonEnable.emit(True)
         self.repo.decrementBusyCount()
@@ -642,7 +646,7 @@ class DetailsDialog(QDialog):
     'Utility dialog for configuring uncommon settings'
     def __init__(self, opts, userhistory, parent):
         QDialog.__init__(self, parent)
-        self.setWindowTitle('%s - commit options' % parent.repo.displayname)
+        self.setWindowTitle(_('%s - commit options') % parent.repo.displayname)
         self.repo = parent.repo
 
         layout = QVBoxLayout()
@@ -923,7 +927,7 @@ class CommitDialog(QDialog):
         bb.button(BB.Discard).setDefault(False)
         bb.button(BB.Ok).setDefault(True)
         self.commitButton = bb.button(BB.Ok)
-        self.commitButton.setText(_('Commit'))
+        self.commitButton.setText(_('Commit', 'action button'))
         self.bb = bb
 
         layout.addWidget(self.bb)
@@ -936,13 +940,20 @@ class CommitDialog(QDialog):
         commit.commitComplete.connect(self.postcommit)
         commit.commitButtonEnable.connect(self.commitButton.setEnabled)
 
-        self.setWindowTitle('%s - commit' % commit.repo.displayname)
+        self.setWindowTitle(_('%s - commit') % commit.repo.displayname)
         self.commit = commit
         self.commit.reload()
         self.updateUndo()
         self.commit.msgte.setFocus()
         QShortcut(QKeySequence.Refresh, self, self.refresh)
 
+    def done(self, ret):
+        self.commit.repo.configChanged.disconnect(self.commit.configChanged)
+        self.commit.repo.repositoryChanged.disconnect(self.commit.repositoryChanged)
+        self.commit.repo.workingBranchChanged.disconnect(self.commit.workingBranchChanged)
+        self.commit.repo.repositoryChanged.disconnect(self.updateUndo)
+        super(CommitDialog, self).done(ret)
+
     def linkActivated(self, link):
         link = hglib.fromunicode(link)
         if link.startswith('subrepo:'):
