@@ -41,7 +41,7 @@ class QuickOpDialog(QDialog):
             command = 'remove'
         self.command = command
 
-        self.setWindowTitle('%s - hg %s' % (repo.displayname, command))
+        self.setWindowTitle(_('%s - hg %s') % (repo.displayname, command))
         self.setWindowIcon(qtlib.geticon(ICONS[command]))
 
         layout = QVBoxLayout()
@@ -112,6 +112,7 @@ class QuickOpDialog(QDialog):
         self.stwidget = stwidget
         self.stwidget.refreshWctx()
         QShortcut(QKeySequence('Ctrl+Return'), self, self.accept)
+        QShortcut(QKeySequence('Ctrl+Enter'), self, self.accept)
         QShortcut(QKeySequence.Refresh, self, self.stwidget.refreshWctx)
         QShortcut(QKeySequence('Escape'), self, self.reject)
 
