@@ -61,7 +61,7 @@ class RepoWidget(QWidget):
         repo.repositoryDestroyed.connect(self.repositoryDestroyed)
         repo.configChanged.connect(self.configChanged)
         self.revsetfilter = False
-        self.branch = ''
+        self.ubranch = u''
         self.bundle = None
         self.revset = []
         self.namedTabs = {}
@@ -156,28 +156,28 @@ class RepoWidget(QWidget):
         w.showMessage.connect(self.showMessage)
         w.updateToRevision.connect(lambda rev: self.updateToRevision())
         self.logTabIndex = idx = tt.addTab(w, qtlib.geticon('hg-log'), '')
-        tt.setTabToolTip(idx, _("Revision details"))
+        tt.setTabToolTip(idx, _("Revision details", "tab tooltip"))
 
         self.commitDemand = w = DemandWidget('createCommitWidget', self)
         self.commitTabIndex = idx = tt.addTab(w, qtlib.geticon('hg-commit'), '')
-        tt.setTabToolTip(idx, _("Commit"))
+        tt.setTabToolTip(idx, _("Commit", "tab tooltip"))
 
         self.syncDemand = w = DemandWidget('createSyncWidget', self)
         self.syncTabIndex = idx = tt.addTab(w, qtlib.geticon('thg-sync'), '')
-        tt.setTabToolTip(idx, _("Synchronize"))
+        tt.setTabToolTip(idx, _("Synchronize", "tab tooltip"))
 
         self.manifestDemand = w = DemandWidget('createManifestWidget', self)
         self.manifestTabIndex = idx = tt.addTab(w, qtlib.geticon('hg-annotate'), '')
-        tt.setTabToolTip(idx, _('Manifest'))
+        tt.setTabToolTip(idx, _("Manifest", "tab tooltip"))
 
         self.grepDemand = w = DemandWidget('createGrepWidget', self)
         self.grepTabIndex = idx = tt.addTab(w, qtlib.geticon('hg-grep'), '')
-        tt.setTabToolTip(idx, _("Search"))
+        tt.setTabToolTip(idx, _("Search", "tab tooltip"))
 
         self.mqDemand = w = DemandWidget('createMQWidget', self)
         if 'mq' in self.repo.extensions():
             self.mqTabIndex = idx = tt.addTab(w, qtlib.geticon('thg-mq'), '')
-            tt.setTabToolTip(idx, _("Patch Queue"))
+            tt.setTabToolTip(idx, _("Patch Queue", "tab tooltip"))
             self.namedTabs['mq'] = idx
         else:
             self.mqTabIndex = -1
@@ -185,7 +185,7 @@ class RepoWidget(QWidget):
         self.pbranchDemand = w = DemandWidget('createPatchBranchWidget', self)
         if 'pbranch' in self.repo.extensions():
             self.pbranchTabIndex = idx = tt.addTab(w, qtlib.geticon('branch'), '')
-            tt.setTabToolTip(idx, _("Patch Branch"))
+            tt.setTabToolTip(idx, _("Patch Branch", "tab tooltip"))
             self.namedTabs['pbranch'] = idx
         else:
             self.pbranchTabIndex = -1
@@ -199,8 +199,8 @@ class RepoWidget(QWidget):
         """Returns the expected title for this widget [unicode]"""
         if self.bundle:
             return _('%s <incoming>') % self.repo.shortname
-        elif self.branch:
-            return '%s [%s]' % (self.repo.shortname, self.branch)
+        elif self.ubranch:
+            return u'%s [%s]' % (self.repo.shortname, self.ubranch)
         else:
             return self.repo.shortname
 
@@ -230,7 +230,7 @@ class RepoWidget(QWidget):
         pats, opts = {}, {}
         cw = CommitWidget(pats, opts, self.repo.root, True, self)
 
-        b = QPushButton(_('Commit'))
+        b = QPushButton(_('Commit', 'action button'))
         b.setAutoDefault(True)
         f = b.font()
         f.setWeight(QFont.Bold)
@@ -575,7 +575,8 @@ class RepoWidget(QWidget):
     def setupModels(self):
         # Filter revision set in case revisions were removed
         self.revset = [r for r in self.revset if r < len(self.repo)]
-        self.repomodel = HgRepoListModel(self.repo, self.branch, self.revset,
+        branch = hglib.fromunicode(self.ubranch)
+        self.repomodel = HgRepoListModel(self.repo, branch, self.revset,
                                          self.revsetfilter, self)
         self.repomodel.filled.connect(self.modelFilled)
         self.repomodel.loaded.connect(self.modelLoaded)
@@ -652,9 +653,12 @@ class RepoWidget(QWidget):
 
     def reload(self):
         'Initiate a refresh of the repo model, rebuild graph'
-        self.repo.thginvalidate()
-        self.rebuildGraph()
-        self.reloadTaskTab()
+        try:
+            self.repo.thginvalidate()
+            self.rebuildGraph()
+            self.reloadTaskTab()
+        except EnvironmentError, e:
+            self.showMessage(hglib.tounicode(str(e)))
 
     def rebuildGraph(self):
         'Called by repositoryChanged signals, and during reload'
@@ -754,10 +758,10 @@ class RepoWidget(QWidget):
         else:
             self.taskTabsWidget.tabBar().hide()
 
-    @pyqtSlot(unicode, bool)
+    @pyqtSlot(QString, bool)
     def setBranch(self, branch, allparents=True):
         'Change the branch filter'
-        self.branch = branch
+        self.ubranch = branch
         self.repomodel.setBranch(branch=branch, allparents=allparents)
         self.titleChanged.emit(self.title())
         if self.revset:
@@ -810,9 +814,12 @@ class RepoWidget(QWidget):
             return False
         s = QSettings()
         if self.isVisible():
-            repoid = str(self.repo[0])
-            s.setValue('repowidget/splitter-'+repoid,
-                       self.repotabs_splitter.saveState())
+            try:
+                repoid = str(self.repo[0])
+                s.setValue('repowidget/splitter-'+repoid,
+                           self.repotabs_splitter.saveState())
+            except EnvironmentError:
+                pass
         self.revDetailsWidget.saveSettings(s)
         self.commitDemand.forward('saveSettings', s, 'workbench')
         self.manifestDemand.forward('saveSettings', s, 'workbench')
@@ -1199,7 +1206,7 @@ class RepoWidget(QWidget):
         if not dir:
             return
         epath = os.path.join(hglib.fromunicode(dir),
-                             self.repo.shortname + '_%r.patch')
+                             hglib.fromunicode(self.repo.shortname)+'_%r.patch')
         cmdline = ['export', '--repository', self.repo.root, '--verbose',
                    '--output', epath]
         for rev in revisions:
