@@ -50,6 +50,7 @@ class RevDetailsWidget(QWidget):
     def setRepo(self, repo):
         self.repo = repo
         self.fileview.setRepo(repo)
+        self.filelist.setRepo(repo)
 
     def setupUi(self):
         SP = QSizePolicy
@@ -209,6 +210,7 @@ class RevDetailsWidget(QWidget):
 
     def create_models(self):
         self.filelistmodel = HgFileListModel(self.repo, self)
+        self.filelistmodel.showMessage.connect(self.showMessage)
 
     def setupModels(self):
         self.create_models()
