@@ -397,12 +397,13 @@ class _QtRunner(QObject):
     def excepthandler(self):
         'Display exception info; run in main (GUI) thread'
         try:
-            self._showexceptiondialog()
-        except:
-            # make sure to quit mainloop first, so that it never leave
-            # zombie process.
-            self._mainapp.exit(1)
-            self._printexception()
+            try:
+                self._showexceptiondialog()
+            except:
+                # make sure to quit mainloop first, so that it never leave
+                # zombie process.
+                self._mainapp.exit(1)
+                self._printexception()
         finally:
             self.errors = []
 
@@ -449,6 +450,7 @@ class _QtRunner(QObject):
             self._mainapp.setOrganizationName('TortoiseHg')
             self._mainapp.setOrganizationDomain('tortoisehg.org')
             self._mainapp.setApplicationVersion(thgversion.version())
+            self._installtranslator()
             qtlib.setup_font_substitutions()
             qtlib.fix_application_font()
             qtlib.configstyles(ui)
@@ -482,6 +484,13 @@ class _QtRunner(QObject):
         finally:
             self._mainapp = None
 
+    def _installtranslator(self):
+        if not i18n.language:
+            return
+        t = QTranslator(self._mainapp)
+        t.load('qt_' + i18n.language, qtlib.gettranslationpath())
+        self._mainapp.installTranslator(t)
+
     def _opendialog(self, dlgfunc, ui, *args, **opts):
         dlg = dlgfunc(ui, *args, **opts)
         if not dlg:
@@ -687,7 +696,10 @@ def annotate(ui, *pats, **opts):
     from tortoisehg.hgqt.annotate import run
     if len(pats) != 1:
         ui.warn(_('annotate requires a single filename\n'))
-        return
+        if pats:
+            pats = pats[0:]
+        else:
+            return
     return qtrun(run, ui, *pats, **opts)
 
 def init(ui, *pats, **opts):
@@ -777,7 +789,7 @@ def help_(ui, name=None, with_version=False, **opts):
         # description
         doc = i[0].__doc__
         if not doc:
-            doc = _("(No help text available)")
+            doc = _("(no help text available)")
         if ui.quiet:
             doc = doc.splitlines(0)[0]
         ui.write("\n%s\n" % doc.rstrip())
@@ -842,7 +854,7 @@ def help_(ui, name=None, with_version=False, **opts):
 
         # description
         if not doc:
-            doc = _("(No help text available)")
+            doc = _("(no help text available)")
         if hasattr(doc, '__call__'):
             doc = doc()
 
@@ -1035,6 +1047,7 @@ table = {
         _('thg strip [-f] [-n] [[-r] REV]')),
     "^rebase": (rebase,
         [('', 'keep', False, _('keep original changesets')),
+         ('', 'keepbranches', False, _('keep original branch names')),
          ('', 'detach', False, _('force detaching of source from its original '
                                 'branch')),
          ('s', 'source', '',
