@@ -183,6 +183,8 @@ class ShelveDialog(QDialog):
 
         self.statusbar = cmdui.ThgStatusBar(self)
         self.layout().addWidget(self.statusbar)
+        self.showMessage(_('Backup copies of modified files can be found '
+                           'in .hg/Trashcan/'))
 
         self.refreshCombos()
         repo.repositoryChanged.connect(self.refreshCombos)
@@ -190,6 +192,10 @@ class ShelveDialog(QDialog):
         self.setWindowTitle(_('TortoiseHg Shelve - %s') % repo.displayname)
         self.restoreSettings()
 
+    def done(self, ret):
+        self.repo.repositoryChanged.disconnect(self.refreshCombos)
+        super(ShelveDialog, self).done(ret)
+
     @pyqtSlot()
     def moveFileRight(self):
         if self.combob.currentIndex() == -1:
