@@ -81,7 +81,10 @@ class ThgRepoWrapper(QObject):
             freq = max(100, int(freq))
         except:
             freq = 500
-        self._timerevent = self.startTimer(freq)
+        if isinstance(repo, bundlerepo.bundlerepository):
+            dbgoutput('not starting timer for bundle repository')
+        else:
+            self._timerevent = self.startTimer(freq)
 
     def timerEvent(self, event):
         if not os.path.exists(self.repo.path):
@@ -611,5 +614,8 @@ def relatedRepositories(repoid):
         for e in repotreemodel.iterRepoItemFromXml(f):
             if e.basenode() == repoid:
                 yield e.rootpath(), e.shortname()
-    finally:
+    except:
+        f.close()
+        raise
+    else:
         f.close()
